# /* **************************************************************************
#  *                                                                          *
#  *     (C) Copyright Paul Mensonides 2002.
#  *     Distributed under the Boost Software License, Version 1.0. (See
#  *     accompanying file LICENSE_1_0.txt or copy at
#  *     http://www.boost.org/LICENSE_1_0.txt)
#  *                                                                          *
#  ************************************************************************** */
#
# /* See http://www.boost.org for most recent version. */
#
# if MSGPACK_PP_LOCAL_R(256)
    MSGPACK_PP_LOCAL_MACRO(256)
# endif
# if MSGPACK_PP_LOCAL_R(255)
    MSGPACK_PP_LOCAL_MACRO(255)
# endif
# if MSGPACK_PP_LOCAL_R(254)
    MSGPACK_PP_LOCAL_MACRO(254)
# endif
# if MSGPACK_PP_LOCAL_R(253)
    MSGPACK_PP_LOCAL_MACRO(253)
# endif
# if MSGPACK_PP_LOCAL_R(252)
    MSGPACK_PP_LOCAL_MACRO(252)
# endif
# if MSGPACK_PP_LOCAL_R(251)
    MSGPACK_PP_LOCAL_MACRO(251)
# endif
# if MSGPACK_PP_LOCAL_R(250)
    MSGPACK_PP_LOCAL_MACRO(250)
# endif
# if MSGPACK_PP_LOCAL_R(249)
    MSGPACK_PP_LOCAL_MACRO(249)
# endif
# if MSGPACK_PP_LOCAL_R(248)
    MSGPACK_PP_LOCAL_MACRO(248)
# endif
# if MSGPACK_PP_LOCAL_R(247)
    MSGPACK_PP_LOCAL_MACRO(247)
# endif
# if MSGPACK_PP_LOCAL_R(246)
    MSGPACK_PP_LOCAL_MACRO(246)
# endif
# if MSGPACK_PP_LOCAL_R(245)
    MSGPACK_PP_LOCAL_MACRO(245)
# endif
# if MSGPACK_PP_LOCAL_R(244)
    MSGPACK_PP_LOCAL_MACRO(244)
# endif
# if MSGPACK_PP_LOCAL_R(243)
    MSGPACK_PP_LOCAL_MACRO(243)
# endif
# if MSGPACK_PP_LOCAL_R(242)
    MSGPACK_PP_LOCAL_MACRO(242)
# endif
# if MSGPACK_PP_LOCAL_R(241)
    MSGPACK_PP_LOCAL_MACRO(241)
# endif
# if MSGPACK_PP_LOCAL_R(240)
    MSGPACK_PP_LOCAL_MACRO(240)
# endif
# if MSGPACK_PP_LOCAL_R(239)
    MSGPACK_PP_LOCAL_MACRO(239)
# endif
# if MSGPACK_PP_LOCAL_R(238)
    MSGPACK_PP_LOCAL_MACRO(238)
# endif
# if MSGPACK_PP_LOCAL_R(237)
    MSGPACK_PP_LOCAL_MACRO(237)
# endif
# if MSGPACK_PP_LOCAL_R(236)
    MSGPACK_PP_LOCAL_MACRO(236)
# endif
# if MSGPACK_PP_LOCAL_R(235)
    MSGPACK_PP_LOCAL_MACRO(235)
# endif
# if MSGPACK_PP_LOCAL_R(234)
    MSGPACK_PP_LOCAL_MACRO(234)
# endif
# if MSGPACK_PP_LOCAL_R(233)
    MSGPACK_PP_LOCAL_MACRO(233)
# endif
# if MSGPACK_PP_LOCAL_R(232)
    MSGPACK_PP_LOCAL_MACRO(232)
# endif
# if MSGPACK_PP_LOCAL_R(231)
    MSGPACK_PP_LOCAL_MACRO(231)
# endif
# if MSGPACK_PP_LOCAL_R(230)
    MSGPACK_PP_LOCAL_MACRO(230)
# endif
# if MSGPACK_PP_LOCAL_R(229)
    MSGPACK_PP_LOCAL_MACRO(229)
# endif
# if MSGPACK_PP_LOCAL_R(228)
    MSGPACK_PP_LOCAL_MACRO(228)
# endif
# if MSGPACK_PP_LOCAL_R(227)
    MSGPACK_PP_LOCAL_MACRO(227)
# endif
# if MSGPACK_PP_LOCAL_R(226)
    MSGPACK_PP_LOCAL_MACRO(226)
# endif
# if MSGPACK_PP_LOCAL_R(225)
    MSGPACK_PP_LOCAL_MACRO(225)
# endif
# if MSGPACK_PP_LOCAL_R(224)
    MSGPACK_PP_LOCAL_MACRO(224)
# endif
# if MSGPACK_PP_LOCAL_R(223)
    MSGPACK_PP_LOCAL_MACRO(223)
# endif
# if MSGPACK_PP_LOCAL_R(222)
    MSGPACK_PP_LOCAL_MACRO(222)
# endif
# if MSGPACK_PP_LOCAL_R(221)
    MSGPACK_PP_LOCAL_MACRO(221)
# endif
# if MSGPACK_PP_LOCAL_R(220)
    MSGPACK_PP_LOCAL_MACRO(220)
# endif
# if MSGPACK_PP_LOCAL_R(219)
    MSGPACK_PP_LOCAL_MACRO(219)
# endif
# if MSGPACK_PP_LOCAL_R(218)
    MSGPACK_PP_LOCAL_MACRO(218)
# endif
# if MSGPACK_PP_LOCAL_R(217)
    MSGPACK_PP_LOCAL_MACRO(217)
# endif
# if MSGPACK_PP_LOCAL_R(216)
    MSGPACK_PP_LOCAL_MACRO(216)
# endif
# if MSGPACK_PP_LOCAL_R(215)
    MSGPACK_PP_LOCAL_MACRO(215)
# endif
# if MSGPACK_PP_LOCAL_R(214)
    MSGPACK_PP_LOCAL_MACRO(214)
# endif
# if MSGPACK_PP_LOCAL_R(213)
    MSGPACK_PP_LOCAL_MACRO(213)
# endif
# if MSGPACK_PP_LOCAL_R(212)
    MSGPACK_PP_LOCAL_MACRO(212)
# endif
# if MSGPACK_PP_LOCAL_R(211)
    MSGPACK_PP_LOCAL_MACRO(211)
# endif
# if MSGPACK_PP_LOCAL_R(210)
    MSGPACK_PP_LOCAL_MACRO(210)
# endif
# if MSGPACK_PP_LOCAL_R(209)
    MSGPACK_PP_LOCAL_MACRO(209)
# endif
# if MSGPACK_PP_LOCAL_R(208)
    MSGPACK_PP_LOCAL_MACRO(208)
# endif
# if MSGPACK_PP_LOCAL_R(207)
    MSGPACK_PP_LOCAL_MACRO(207)
# endif
# if MSGPACK_PP_LOCAL_R(206)
    MSGPACK_PP_LOCAL_MACRO(206)
# endif
# if MSGPACK_PP_LOCAL_R(205)
    MSGPACK_PP_LOCAL_MACRO(205)
# endif
# if MSGPACK_PP_LOCAL_R(204)
    MSGPACK_PP_LOCAL_MACRO(204)
# endif
# if MSGPACK_PP_LOCAL_R(203)
    MSGPACK_PP_LOCAL_MACRO(203)
# endif
# if MSGPACK_PP_LOCAL_R(202)
    MSGPACK_PP_LOCAL_MACRO(202)
# endif
# if MSGPACK_PP_LOCAL_R(201)
    MSGPACK_PP_LOCAL_MACRO(201)
# endif
# if MSGPACK_PP_LOCAL_R(200)
    MSGPACK_PP_LOCAL_MACRO(200)
# endif
# if MSGPACK_PP_LOCAL_R(199)
    MSGPACK_PP_LOCAL_MACRO(199)
# endif
# if MSGPACK_PP_LOCAL_R(198)
    MSGPACK_PP_LOCAL_MACRO(198)
# endif
# if MSGPACK_PP_LOCAL_R(197)
    MSGPACK_PP_LOCAL_MACRO(197)
# endif
# if MSGPACK_PP_LOCAL_R(196)
    MSGPACK_PP_LOCAL_MACRO(196)
# endif
# if MSGPACK_PP_LOCAL_R(195)
    MSGPACK_PP_LOCAL_MACRO(195)
# endif
# if MSGPACK_PP_LOCAL_R(194)
    MSGPACK_PP_LOCAL_MACRO(194)
# endif
# if MSGPACK_PP_LOCAL_R(193)
    MSGPACK_PP_LOCAL_MACRO(193)
# endif
# if MSGPACK_PP_LOCAL_R(192)
    MSGPACK_PP_LOCAL_MACRO(192)
# endif
# if MSGPACK_PP_LOCAL_R(191)
    MSGPACK_PP_LOCAL_MACRO(191)
# endif
# if MSGPACK_PP_LOCAL_R(190)
    MSGPACK_PP_LOCAL_MACRO(190)
# endif
# if MSGPACK_PP_LOCAL_R(189)
    MSGPACK_PP_LOCAL_MACRO(189)
# endif
# if MSGPACK_PP_LOCAL_R(188)
    MSGPACK_PP_LOCAL_MACRO(188)
# endif
# if MSGPACK_PP_LOCAL_R(187)
    MSGPACK_PP_LOCAL_MACRO(187)
# endif
# if MSGPACK_PP_LOCAL_R(186)
    MSGPACK_PP_LOCAL_MACRO(186)
# endif
# if MSGPACK_PP_LOCAL_R(185)
    MSGPACK_PP_LOCAL_MACRO(185)
# endif
# if MSGPACK_PP_LOCAL_R(184)
    MSGPACK_PP_LOCAL_MACRO(184)
# endif
# if MSGPACK_PP_LOCAL_R(183)
    MSGPACK_PP_LOCAL_MACRO(183)
# endif
# if MSGPACK_PP_LOCAL_R(182)
    MSGPACK_PP_LOCAL_MACRO(182)
# endif
# if MSGPACK_PP_LOCAL_R(181)
    MSGPACK_PP_LOCAL_MACRO(181)
# endif
# if MSGPACK_PP_LOCAL_R(180)
    MSGPACK_PP_LOCAL_MACRO(180)
# endif
# if MSGPACK_PP_LOCAL_R(179)
    MSGPACK_PP_LOCAL_MACRO(179)
# endif
# if MSGPACK_PP_LOCAL_R(178)
    MSGPACK_PP_LOCAL_MACRO(178)
# endif
# if MSGPACK_PP_LOCAL_R(177)
    MSGPACK_PP_LOCAL_MACRO(177)
# endif
# if MSGPACK_PP_LOCAL_R(176)
    MSGPACK_PP_LOCAL_MACRO(176)
# endif
# if MSGPACK_PP_LOCAL_R(175)
    MSGPACK_PP_LOCAL_MACRO(175)
# endif
# if MSGPACK_PP_LOCAL_R(174)
    MSGPACK_PP_LOCAL_MACRO(174)
# endif
# if MSGPACK_PP_LOCAL_R(173)
    MSGPACK_PP_LOCAL_MACRO(173)
# endif
# if MSGPACK_PP_LOCAL_R(172)
    MSGPACK_PP_LOCAL_MACRO(172)
# endif
# if MSGPACK_PP_LOCAL_R(171)
    MSGPACK_PP_LOCAL_MACRO(171)
# endif
# if MSGPACK_PP_LOCAL_R(170)
    MSGPACK_PP_LOCAL_MACRO(170)
# endif
# if MSGPACK_PP_LOCAL_R(169)
    MSGPACK_PP_LOCAL_MACRO(169)
# endif
# if MSGPACK_PP_LOCAL_R(168)
    MSGPACK_PP_LOCAL_MACRO(168)
# endif
# if MSGPACK_PP_LOCAL_R(167)
    MSGPACK_PP_LOCAL_MACRO(167)
# endif
# if MSGPACK_PP_LOCAL_R(166)
    MSGPACK_PP_LOCAL_MACRO(166)
# endif
# if MSGPACK_PP_LOCAL_R(165)
    MSGPACK_PP_LOCAL_MACRO(165)
# endif
# if MSGPACK_PP_LOCAL_R(164)
    MSGPACK_PP_LOCAL_MACRO(164)
# endif
# if MSGPACK_PP_LOCAL_R(163)
    MSGPACK_PP_LOCAL_MACRO(163)
# endif
# if MSGPACK_PP_LOCAL_R(162)
    MSGPACK_PP_LOCAL_MACRO(162)
# endif
# if MSGPACK_PP_LOCAL_R(161)
    MSGPACK_PP_LOCAL_MACRO(161)
# endif
# if MSGPACK_PP_LOCAL_R(160)
    MSGPACK_PP_LOCAL_MACRO(160)
# endif
# if MSGPACK_PP_LOCAL_R(159)
    MSGPACK_PP_LOCAL_MACRO(159)
# endif
# if MSGPACK_PP_LOCAL_R(158)
    MSGPACK_PP_LOCAL_MACRO(158)
# endif
# if MSGPACK_PP_LOCAL_R(157)
    MSGPACK_PP_LOCAL_MACRO(157)
# endif
# if MSGPACK_PP_LOCAL_R(156)
    MSGPACK_PP_LOCAL_MACRO(156)
# endif
# if MSGPACK_PP_LOCAL_R(155)
    MSGPACK_PP_LOCAL_MACRO(155)
# endif
# if MSGPACK_PP_LOCAL_R(154)
    MSGPACK_PP_LOCAL_MACRO(154)
# endif
# if MSGPACK_PP_LOCAL_R(153)
    MSGPACK_PP_LOCAL_MACRO(153)
# endif
# if MSGPACK_PP_LOCAL_R(152)
    MSGPACK_PP_LOCAL_MACRO(152)
# endif
# if MSGPACK_PP_LOCAL_R(151)
    MSGPACK_PP_LOCAL_MACRO(151)
# endif
# if MSGPACK_PP_LOCAL_R(150)
    MSGPACK_PP_LOCAL_MACRO(150)
# endif
# if MSGPACK_PP_LOCAL_R(149)
    MSGPACK_PP_LOCAL_MACRO(149)
# endif
# if MSGPACK_PP_LOCAL_R(148)
    MSGPACK_PP_LOCAL_MACRO(148)
# endif
# if MSGPACK_PP_LOCAL_R(147)
    MSGPACK_PP_LOCAL_MACRO(147)
# endif
# if MSGPACK_PP_LOCAL_R(146)
    MSGPACK_PP_LOCAL_MACRO(146)
# endif
# if MSGPACK_PP_LOCAL_R(145)
    MSGPACK_PP_LOCAL_MACRO(145)
# endif
# if MSGPACK_PP_LOCAL_R(144)
    MSGPACK_PP_LOCAL_MACRO(144)
# endif
# if MSGPACK_PP_LOCAL_R(143)
    MSGPACK_PP_LOCAL_MACRO(143)
# endif
# if MSGPACK_PP_LOCAL_R(142)
    MSGPACK_PP_LOCAL_MACRO(142)
# endif
# if MSGPACK_PP_LOCAL_R(141)
    MSGPACK_PP_LOCAL_MACRO(141)
# endif
# if MSGPACK_PP_LOCAL_R(140)
    MSGPACK_PP_LOCAL_MACRO(140)
# endif
# if MSGPACK_PP_LOCAL_R(139)
    MSGPACK_PP_LOCAL_MACRO(139)
# endif
# if MSGPACK_PP_LOCAL_R(138)
    MSGPACK_PP_LOCAL_MACRO(138)
# endif
# if MSGPACK_PP_LOCAL_R(137)
    MSGPACK_PP_LOCAL_MACRO(137)
# endif
# if MSGPACK_PP_LOCAL_R(136)
    MSGPACK_PP_LOCAL_MACRO(136)
# endif
# if MSGPACK_PP_LOCAL_R(135)
    MSGPACK_PP_LOCAL_MACRO(135)
# endif
# if MSGPACK_PP_LOCAL_R(134)
    MSGPACK_PP_LOCAL_MACRO(134)
# endif
# if MSGPACK_PP_LOCAL_R(133)
    MSGPACK_PP_LOCAL_MACRO(133)
# endif
# if MSGPACK_PP_LOCAL_R(132)
    MSGPACK_PP_LOCAL_MACRO(132)
# endif
# if MSGPACK_PP_LOCAL_R(131)
    MSGPACK_PP_LOCAL_MACRO(131)
# endif
# if MSGPACK_PP_LOCAL_R(130)
    MSGPACK_PP_LOCAL_MACRO(130)
# endif
# if MSGPACK_PP_LOCAL_R(129)
    MSGPACK_PP_LOCAL_MACRO(129)
# endif
# if MSGPACK_PP_LOCAL_R(128)
    MSGPACK_PP_LOCAL_MACRO(128)
# endif
# if MSGPACK_PP_LOCAL_R(127)
    MSGPACK_PP_LOCAL_MACRO(127)
# endif
# if MSGPACK_PP_LOCAL_R(126)
    MSGPACK_PP_LOCAL_MACRO(126)
# endif
# if MSGPACK_PP_LOCAL_R(125)
    MSGPACK_PP_LOCAL_MACRO(125)
# endif
# if MSGPACK_PP_LOCAL_R(124)
    MSGPACK_PP_LOCAL_MACRO(124)
# endif
# if MSGPACK_PP_LOCAL_R(123)
    MSGPACK_PP_LOCAL_MACRO(123)
# endif
# if MSGPACK_PP_LOCAL_R(122)
    MSGPACK_PP_LOCAL_MACRO(122)
# endif
# if MSGPACK_PP_LOCAL_R(121)
    MSGPACK_PP_LOCAL_MACRO(121)
# endif
# if MSGPACK_PP_LOCAL_R(120)
    MSGPACK_PP_LOCAL_MACRO(120)
# endif
# if MSGPACK_PP_LOCAL_R(119)
    MSGPACK_PP_LOCAL_MACRO(119)
# endif
# if MSGPACK_PP_LOCAL_R(118)
    MSGPACK_PP_LOCAL_MACRO(118)
# endif
# if MSGPACK_PP_LOCAL_R(117)
    MSGPACK_PP_LOCAL_MACRO(117)
# endif
# if MSGPACK_PP_LOCAL_R(116)
    MSGPACK_PP_LOCAL_MACRO(116)
# endif
# if MSGPACK_PP_LOCAL_R(115)
    MSGPACK_PP_LOCAL_MACRO(115)
# endif
# if MSGPACK_PP_LOCAL_R(114)
    MSGPACK_PP_LOCAL_MACRO(114)
# endif
# if MSGPACK_PP_LOCAL_R(113)
    MSGPACK_PP_LOCAL_MACRO(113)
# endif
# if MSGPACK_PP_LOCAL_R(112)
    MSGPACK_PP_LOCAL_MACRO(112)
# endif
# if MSGPACK_PP_LOCAL_R(111)
    MSGPACK_PP_LOCAL_MACRO(111)
# endif
# if MSGPACK_PP_LOCAL_R(110)
    MSGPACK_PP_LOCAL_MACRO(110)
# endif
# if MSGPACK_PP_LOCAL_R(109)
    MSGPACK_PP_LOCAL_MACRO(109)
# endif
# if MSGPACK_PP_LOCAL_R(108)
    MSGPACK_PP_LOCAL_MACRO(108)
# endif
# if MSGPACK_PP_LOCAL_R(107)
    MSGPACK_PP_LOCAL_MACRO(107)
# endif
# if MSGPACK_PP_LOCAL_R(106)
    MSGPACK_PP_LOCAL_MACRO(106)
# endif
# if MSGPACK_PP_LOCAL_R(105)
    MSGPACK_PP_LOCAL_MACRO(105)
# endif
# if MSGPACK_PP_LOCAL_R(104)
    MSGPACK_PP_LOCAL_MACRO(104)
# endif
# if MSGPACK_PP_LOCAL_R(103)
    MSGPACK_PP_LOCAL_MACRO(103)
# endif
# if MSGPACK_PP_LOCAL_R(102)
    MSGPACK_PP_LOCAL_MACRO(102)
# endif
# if MSGPACK_PP_LOCAL_R(101)
    MSGPACK_PP_LOCAL_MACRO(101)
# endif
# if MSGPACK_PP_LOCAL_R(100)
    MSGPACK_PP_LOCAL_MACRO(100)
# endif
# if MSGPACK_PP_LOCAL_R(99)
    MSGPACK_PP_LOCAL_MACRO(99)
# endif
# if MSGPACK_PP_LOCAL_R(98)
    MSGPACK_PP_LOCAL_MACRO(98)
# endif
# if MSGPACK_PP_LOCAL_R(97)
    MSGPACK_PP_LOCAL_MACRO(97)
# endif
# if MSGPACK_PP_LOCAL_R(96)
    MSGPACK_PP_LOCAL_MACRO(96)
# endif
# if MSGPACK_PP_LOCAL_R(95)
    MSGPACK_PP_LOCAL_MACRO(95)
# endif
# if MSGPACK_PP_LOCAL_R(94)
    MSGPACK_PP_LOCAL_MACRO(94)
# endif
# if MSGPACK_PP_LOCAL_R(93)
    MSGPACK_PP_LOCAL_MACRO(93)
# endif
# if MSGPACK_PP_LOCAL_R(92)
    MSGPACK_PP_LOCAL_MACRO(92)
# endif
# if MSGPACK_PP_LOCAL_R(91)
    MSGPACK_PP_LOCAL_MACRO(91)
# endif
# if MSGPACK_PP_LOCAL_R(90)
    MSGPACK_PP_LOCAL_MACRO(90)
# endif
# if MSGPACK_PP_LOCAL_R(89)
    MSGPACK_PP_LOCAL_MACRO(89)
# endif
# if MSGPACK_PP_LOCAL_R(88)
    MSGPACK_PP_LOCAL_MACRO(88)
# endif
# if MSGPACK_PP_LOCAL_R(87)
    MSGPACK_PP_LOCAL_MACRO(87)
# endif
# if MSGPACK_PP_LOCAL_R(86)
    MSGPACK_PP_LOCAL_MACRO(86)
# endif
# if MSGPACK_PP_LOCAL_R(85)
    MSGPACK_PP_LOCAL_MACRO(85)
# endif
# if MSGPACK_PP_LOCAL_R(84)
    MSGPACK_PP_LOCAL_MACRO(84)
# endif
# if MSGPACK_PP_LOCAL_R(83)
    MSGPACK_PP_LOCAL_MACRO(83)
# endif
# if MSGPACK_PP_LOCAL_R(82)
    MSGPACK_PP_LOCAL_MACRO(82)
# endif
# if MSGPACK_PP_LOCAL_R(81)
    MSGPACK_PP_LOCAL_MACRO(81)
# endif
# if MSGPACK_PP_LOCAL_R(80)
    MSGPACK_PP_LOCAL_MACRO(80)
# endif
# if MSGPACK_PP_LOCAL_R(79)
    MSGPACK_PP_LOCAL_MACRO(79)
# endif
# if MSGPACK_PP_LOCAL_R(78)
    MSGPACK_PP_LOCAL_MACRO(78)
# endif
# if MSGPACK_PP_LOCAL_R(77)
    MSGPACK_PP_LOCAL_MACRO(77)
# endif
# if MSGPACK_PP_LOCAL_R(76)
    MSGPACK_PP_LOCAL_MACRO(76)
# endif
# if MSGPACK_PP_LOCAL_R(75)
    MSGPACK_PP_LOCAL_MACRO(75)
# endif
# if MSGPACK_PP_LOCAL_R(74)
    MSGPACK_PP_LOCAL_MACRO(74)
# endif
# if MSGPACK_PP_LOCAL_R(73)
    MSGPACK_PP_LOCAL_MACRO(73)
# endif
# if MSGPACK_PP_LOCAL_R(72)
    MSGPACK_PP_LOCAL_MACRO(72)
# endif
# if MSGPACK_PP_LOCAL_R(71)
    MSGPACK_PP_LOCAL_MACRO(71)
# endif
# if MSGPACK_PP_LOCAL_R(70)
    MSGPACK_PP_LOCAL_MACRO(70)
# endif
# if MSGPACK_PP_LOCAL_R(69)
    MSGPACK_PP_LOCAL_MACRO(69)
# endif
# if MSGPACK_PP_LOCAL_R(68)
    MSGPACK_PP_LOCAL_MACRO(68)
# endif
# if MSGPACK_PP_LOCAL_R(67)
    MSGPACK_PP_LOCAL_MACRO(67)
# endif
# if MSGPACK_PP_LOCAL_R(66)
    MSGPACK_PP_LOCAL_MACRO(66)
# endif
# if MSGPACK_PP_LOCAL_R(65)
    MSGPACK_PP_LOCAL_MACRO(65)
# endif
# if MSGPACK_PP_LOCAL_R(64)
    MSGPACK_PP_LOCAL_MACRO(64)
# endif
# if MSGPACK_PP_LOCAL_R(63)
    MSGPACK_PP_LOCAL_MACRO(63)
# endif
# if MSGPACK_PP_LOCAL_R(62)
    MSGPACK_PP_LOCAL_MACRO(62)
# endif
# if MSGPACK_PP_LOCAL_R(61)
    MSGPACK_PP_LOCAL_MACRO(61)
# endif
# if MSGPACK_PP_LOCAL_R(60)
    MSGPACK_PP_LOCAL_MACRO(60)
# endif
# if MSGPACK_PP_LOCAL_R(59)
    MSGPACK_PP_LOCAL_MACRO(59)
# endif
# if MSGPACK_PP_LOCAL_R(58)
    MSGPACK_PP_LOCAL_MACRO(58)
# endif
# if MSGPACK_PP_LOCAL_R(57)
    MSGPACK_PP_LOCAL_MACRO(57)
# endif
# if MSGPACK_PP_LOCAL_R(56)
    MSGPACK_PP_LOCAL_MACRO(56)
# endif
# if MSGPACK_PP_LOCAL_R(55)
    MSGPACK_PP_LOCAL_MACRO(55)
# endif
# if MSGPACK_PP_LOCAL_R(54)
    MSGPACK_PP_LOCAL_MACRO(54)
# endif
# if MSGPACK_PP_LOCAL_R(53)
    MSGPACK_PP_LOCAL_MACRO(53)
# endif
# if MSGPACK_PP_LOCAL_R(52)
    MSGPACK_PP_LOCAL_MACRO(52)
# endif
# if MSGPACK_PP_LOCAL_R(51)
    MSGPACK_PP_LOCAL_MACRO(51)
# endif
# if MSGPACK_PP_LOCAL_R(50)
    MSGPACK_PP_LOCAL_MACRO(50)
# endif
# if MSGPACK_PP_LOCAL_R(49)
    MSGPACK_PP_LOCAL_MACRO(49)
# endif
# if MSGPACK_PP_LOCAL_R(48)
    MSGPACK_PP_LOCAL_MACRO(48)
# endif
# if MSGPACK_PP_LOCAL_R(47)
    MSGPACK_PP_LOCAL_MACRO(47)
# endif
# if MSGPACK_PP_LOCAL_R(46)
    MSGPACK_PP_LOCAL_MACRO(46)
# endif
# if MSGPACK_PP_LOCAL_R(45)
    MSGPACK_PP_LOCAL_MACRO(45)
# endif
# if MSGPACK_PP_LOCAL_R(44)
    MSGPACK_PP_LOCAL_MACRO(44)
# endif
# if MSGPACK_PP_LOCAL_R(43)
    MSGPACK_PP_LOCAL_MACRO(43)
# endif
# if MSGPACK_PP_LOCAL_R(42)
    MSGPACK_PP_LOCAL_MACRO(42)
# endif
# if MSGPACK_PP_LOCAL_R(41)
    MSGPACK_PP_LOCAL_MACRO(41)
# endif
# if MSGPACK_PP_LOCAL_R(40)
    MSGPACK_PP_LOCAL_MACRO(40)
# endif
# if MSGPACK_PP_LOCAL_R(39)
    MSGPACK_PP_LOCAL_MACRO(39)
# endif
# if MSGPACK_PP_LOCAL_R(38)
    MSGPACK_PP_LOCAL_MACRO(38)
# endif
# if MSGPACK_PP_LOCAL_R(37)
    MSGPACK_PP_LOCAL_MACRO(37)
# endif
# if MSGPACK_PP_LOCAL_R(36)
    MSGPACK_PP_LOCAL_MACRO(36)
# endif
# if MSGPACK_PP_LOCAL_R(35)
    MSGPACK_PP_LOCAL_MACRO(35)
# endif
# if MSGPACK_PP_LOCAL_R(34)
    MSGPACK_PP_LOCAL_MACRO(34)
# endif
# if MSGPACK_PP_LOCAL_R(33)
    MSGPACK_PP_LOCAL_MACRO(33)
# endif
# if MSGPACK_PP_LOCAL_R(32)
    MSGPACK_PP_LOCAL_MACRO(32)
# endif
# if MSGPACK_PP_LOCAL_R(31)
    MSGPACK_PP_LOCAL_MACRO(31)
# endif
# if MSGPACK_PP_LOCAL_R(30)
    MSGPACK_PP_LOCAL_MACRO(30)
# endif
# if MSGPACK_PP_LOCAL_R(29)
    MSGPACK_PP_LOCAL_MACRO(29)
# endif
# if MSGPACK_PP_LOCAL_R(28)
    MSGPACK_PP_LOCAL_MACRO(28)
# endif
# if MSGPACK_PP_LOCAL_R(27)
    MSGPACK_PP_LOCAL_MACRO(27)
# endif
# if MSGPACK_PP_LOCAL_R(26)
    MSGPACK_PP_LOCAL_MACRO(26)
# endif
# if MSGPACK_PP_LOCAL_R(25)
    MSGPACK_PP_LOCAL_MACRO(25)
# endif
# if MSGPACK_PP_LOCAL_R(24)
    MSGPACK_PP_LOCAL_MACRO(24)
# endif
# if MSGPACK_PP_LOCAL_R(23)
    MSGPACK_PP_LOCAL_MACRO(23)
# endif
# if MSGPACK_PP_LOCAL_R(22)
    MSGPACK_PP_LOCAL_MACRO(22)
# endif
# if MSGPACK_PP_LOCAL_R(21)
    MSGPACK_PP_LOCAL_MACRO(21)
# endif
# if MSGPACK_PP_LOCAL_R(20)
    MSGPACK_PP_LOCAL_MACRO(20)
# endif
# if MSGPACK_PP_LOCAL_R(19)
    MSGPACK_PP_LOCAL_MACRO(19)
# endif
# if MSGPACK_PP_LOCAL_R(18)
    MSGPACK_PP_LOCAL_MACRO(18)
# endif
# if MSGPACK_PP_LOCAL_R(17)
    MSGPACK_PP_LOCAL_MACRO(17)
# endif
# if MSGPACK_PP_LOCAL_R(16)
    MSGPACK_PP_LOCAL_MACRO(16)
# endif
# if MSGPACK_PP_LOCAL_R(15)
    MSGPACK_PP_LOCAL_MACRO(15)
# endif
# if MSGPACK_PP_LOCAL_R(14)
    MSGPACK_PP_LOCAL_MACRO(14)
# endif
# if MSGPACK_PP_LOCAL_R(13)
    MSGPACK_PP_LOCAL_MACRO(13)
# endif
# if MSGPACK_PP_LOCAL_R(12)
    MSGPACK_PP_LOCAL_MACRO(12)
# endif
# if MSGPACK_PP_LOCAL_R(11)
    MSGPACK_PP_LOCAL_MACRO(11)
# endif
# if MSGPACK_PP_LOCAL_R(10)
    MSGPACK_PP_LOCAL_MACRO(10)
# endif
# if MSGPACK_PP_LOCAL_R(9)
    MSGPACK_PP_LOCAL_MACRO(9)
# endif
# if MSGPACK_PP_LOCAL_R(8)
    MSGPACK_PP_LOCAL_MACRO(8)
# endif
# if MSGPACK_PP_LOCAL_R(7)
    MSGPACK_PP_LOCAL_MACRO(7)
# endif
# if MSGPACK_PP_LOCAL_R(6)
    MSGPACK_PP_LOCAL_MACRO(6)
# endif
# if MSGPACK_PP_LOCAL_R(5)
    MSGPACK_PP_LOCAL_MACRO(5)
# endif
# if MSGPACK_PP_LOCAL_R(4)
    MSGPACK_PP_LOCAL_MACRO(4)
# endif
# if MSGPACK_PP_LOCAL_R(3)
    MSGPACK_PP_LOCAL_MACRO(3)
# endif
# if MSGPACK_PP_LOCAL_R(2)
    MSGPACK_PP_LOCAL_MACRO(2)
# endif
# if MSGPACK_PP_LOCAL_R(1)
    MSGPACK_PP_LOCAL_MACRO(1)
# endif
# if MSGPACK_PP_LOCAL_R(0)
    MSGPACK_PP_LOCAL_MACRO(0)
# endif
